# Architecture

## CLI Architecture

1.  CLI usage starts in `bin/tslint-to-eslint-config`, which immediately calls `src/cli/main.ts`.
2.  CLI settings are parsed and read in `src/cli/runCli.ts`.
3.  Linter configuration conversion is run by `src/conversion/convertConfig.ts`.
4.  Editor configuration conversion is run by `src/conversion/convertEditorConfig.ts`.

## Linter Configuration Conversion

Within `src/conversion/convertConfig.ts`, the following steps occur:

1. Existing configurations are read from disk
2. TSLint rules are converted into their ESLint configurations
3. ESLint configurations are summarized based on extended ESLint and TSLint presets
    - 3a. If no output rules conflict with `eslint-config-prettier`, it's added in
    - 3b. Any ESLint rules that are configured the same as an extended preset are trimmed
4. The summarized configuration is written to the output config file
5. Files to transform comments in have source text rewritten using the same rule conversion logic
6. A summary of the results is printed to the user's console

### Conversion Results

The overall configuration generated by steps 2-3 and printed in 4-5 contains the following information:

### Rule Converters

Each TSLint rule should output at least one ESLint rule as the equivalent.
"Converters" for TSLint rules are located in `src/rules/converters/`, and keyed under their names by the map in `src/rules/converters.ts`.

Each converter for a TSLint rule takes an arguments object for the rule, and returns an array of objects containing:

-   `rules`: At least one equivalent ESLint rule and options
-   `notices`: Any extra info that should be printed after conversion
-   `plugins`: Any plugins that should now be installed if not already

The `rules` output is an array of objects containing:

-   `ruleName`: Equivalent ESLint rule name that should be enabled
-   `ruleArguments`: Any arguments for that ESLint rule

Multiple objects must be supported because some general-use TSLint rules can only be represented by two or more ESLint rules.
For example, TSLint's `no-banned-terms` is represented by ESLint's `no-caller` and `no-eval`.

### Rule Mergers

It's possible that one ESLint rule will be output by multiple converters.
"Mergers" for those ESLint rules should take in two configurations to the same rule and output the equivalent single configuration.
These are located in `src/rules/mergers/`, and keyed under their names by the map in `src/rules/mergers.ts`.

For example, `@typescript-eslint/ban-types` spreads both arguments' `types` members into one large `types` object.

## Editor Configuration Conversion

Editor lint configurations are converted by `src/editorSettings/convertEditorSettings.ts`.
Any setting that matches a known built-in TSLint setting will be replaced with the ESLint equivalent.
